```
Usage: vcd vc attach [OPTIONS] <vc-name>

Options:
  --vc-host [vc-host]             vc host name (vc.server.example.com, or
                                  something similar)  [required]
  --vc-user [vc-user]             VC admin user name  [required]
  --vc-pwd [vc-pwd]               VC admin password  [required]
  -e, --enable [enable]           enable flag (boolean: True or False)
                                  [required]
  --vc-root-folder [vc-root-folder]
                                  VC root folder (for a future release - VCD
                                  API version 31.0)
  --nsx-server-name [nsx-server-name]
                                  NSX server name
  --nsx-host [nsx-host]           NSX host name (nsx.server.example.com, or
                                  something similar)
  --nsx-user [nsx-user]           NSX admin user name
  --nsx-pwd [nsx-pwd]             NSX admin password
  -h, --help                      Show this message and exit.

```
